Class: Magicka::MethodBuilder Private
- Inherits:
-
Sinclair
- Object
- Sinclair
- Magicka::MethodBuilder
- Defined in:
- lib/magicka/method_builder.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
class responsible for building methods on Element
Instance Method Summary collapse
-
#add_template(template) ⇒ Array<Sinclair::MethodDefinition>
private
adds a mehtod
#template. -
#add_template_folder(folder) ⇒ Array<Sinclair::MethodDefinition>
private
adds a mehtod
#template_folder.
Instance Method Details
#add_template(template) ⇒ Array<Sinclair::MethodDefinition>
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
adds a mehtod #template
The method will always return the template given in the params
15 16 17 18 19 20 21 |
# File 'lib/magicka/method_builder.rb', line 15 def add_template(template) add_method(:template) do template end build end |
#add_template_folder(folder) ⇒ Array<Sinclair::MethodDefinition>
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
adds a mehtod #template_folder
The method will always return the template folder given in the params
30 31 32 33 34 35 36 |
# File 'lib/magicka/method_builder.rb', line 30 def add_template_folder(folder) add_method(:template_folder) do folder end build end |